<img align="left" width="100" height="100" src="https://github.com/oplab-team/oplab-client-python/blob/master/bin/python_logo.png?raw=true">

# oplab-client-python

[![PyPI version fury.io](https://badge.fury.io/py/oplab-client-python.svg)](https://pypi.org/project/oplab-client-python/)
<img src="https://img.shields.io/discord/701830367912656928?logo=discord"
            alt="chat on Discord"></a>

## Description

This pip package's intent is to provide a safe and easy way to interact with [Oplab's public API](https://apidocs.oplab.com.br). With it, you should be able to use the latest feature additions to the API as we publish them.

## Installation

`pip install oplab-client-python`

## Usage

// TODO

## Support

You can go to our Discord server and ask for some help over the **[#devtalk](https://discord.gg/FyskfG8JUq)** channel. You can also just open an issue asking for help. Use the `help` label.

## Roadmap

If you have ideas for releases in the future, it is a good idea to list them in the README.

## Contributing

We accept contributions. Just send us a pull request if you have some improvement to contribute!

## Authors and acknowledgment

Made with care by the oplab-team.

## License

MIT

## Project status

This project is still @ it's dawn. If you feel like contributing, or participating in any forms, just send us an issue.
